==> fswiki-3.5.6.tbz: share/fswiki/plugin/attach/Files.pm <==
############################################################
#
# <p>ΥڡźդƤեɽޤ</p>
# <p>FooterMenu˵ҤƤǤ</p>
# <pre>
# {{files}}
# </pre>
# <p>Menu˵ҤʤɡvץĤȽĤɽ뤳ȤǤޤ</p>
# <pre>
# {{files v}}
# </pre>
#
############################################################
package plugin::attach::Files;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# źեեΰɽ륤饤ؿ
#===========================================================
sub paragraph {
	my $self = shift;
	my $wiki = shift;
	my $way  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if(!defined($way)){
		$way = "";
	}
	# ȸ뤫ɤĴ٤
	unless($wiki->can_show($pagename)){
		return undef;
	}
	
	my ($entry,$buf);
	
	my $editFlag = 1;
	my $login = $wiki->get_login_info();
	if($wiki->is_freeze($pagename) && (!defined($login) || $login->{type}!=0)){
		$editFlag = 0;
	} elsif(($wiki->config('accept_edit')==0 || $wiki->config('accept_attach_delete')==0) && !defined($login)){
		$editFlag = 0;
	}
	
	if($way eq "V" || $way eq "v"){
		$buf = "<ul>\n";
	}
	
	foreach my $file (&get_file_list($wiki,$pagename)){
		if($way eq "V" || $way eq "v"){
			$buf = $buf."<li><a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		} else {
			$buf = $buf."<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		}
		
		if($editFlag){
			$buf .= "[<a href=\"".$wiki->config('script_name')."?action=ATTACH&CONFIRM=yes&page=".
			        &Util::url_encode($pagename)."&file=".&Util::url_encode($file)."\"></a>]";
		}
		
		if($way eq "V" || $way eq "v"){
			$buf .= "</li>\n";
		} else {
			$buf .= "\n";
		}
	}
	
	if($way eq "V" || $way eq "v"){
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

#===========================================================
# եΰؿ
#===========================================================
sub get_file_list {
	my $wiki = shift;
	my $page = shift;
	my $encode_page = &Util::url_encode($page);
	my @list;
	if(-e $wiki->config('attach_dir')){
		opendir(DIR,$wiki->config('attach_dir')) or die $!;
		while(my $entry = readdir(DIR)){
			if(index($entry,$encode_page.".")==0){
				my $file = (split(/\./,$entry))[1];
				push(@list,&Util::url_decode($file));
			}
		}
		closedir(DIR);
	}
	@list = sort { $a cmp $b } @list;
	return @list;
}

1;

==> fswiki-3.6.2_1.tbz: share/fswiki/plugin/attach/Files.pm <==
############################################################
#
# <p>ΥڡźդƤեɽޤ</p>
# <p>FooterMenu˵ҤƤǤ</p>
# <pre>
# {{files}}
# </pre>
# <p>Menu˵ҤʤɡvץĤȽĤɽ뤳ȤǤޤ</p>
# <pre>
# {{files v}}
# </pre>
#
############################################################
package plugin::attach::Files;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# źեեΰɽ륤饤ؿ
#===========================================================
sub paragraph {
	my $self = shift;
	my $wiki = shift;
	my $way  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if(!defined($way)){
		$way = "";
	}
	# ȸ뤫ɤĴ٤
	unless($wiki->can_show($pagename)){
		return undef;
	}
	
	my ($entry,$buf);
	
	my $editFlag = &can_attach_delete($wiki, $pagename);
#	my $login = $wiki->get_login_info();
#	if(!$wiki->can_modify_page($pagename)){
#		$editFlag = 0;
#	} elsif($wiki->config('accept_attach_delete')==0 && !defined($login)){
#		$editFlag = 0;
#	} elsif($wiki->config('accept_attach_delete')==2 && (!defined($login) || $login->{type}!=0)){
#		$editFlag = 0;
#	}
	
	if($way eq "V" || $way eq "v"){
		$buf = "<ul>\n";
	}
	
	foreach my $file (&get_file_list($wiki,$pagename)){
		if($way eq "V" || $way eq "v"){
			$buf = $buf."<li><a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		} else {
			$buf = $buf."<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		}
		
		if($editFlag){
			$buf .= "[<a href=\"".$wiki->config('script_name')."?action=ATTACH&CONFIRM=yes&page=".
			        &Util::url_encode($pagename)."&file=".&Util::url_encode($file)."\"></a>]";
		}
		
		if($way eq "V" || $way eq "v"){
			$buf .= "</li>\n";
		} else {
			$buf .= "\n";
		}
	}
	
	if($way eq "V" || $way eq "v"){
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

#===========================================================
# եΰؿ
#===========================================================
sub get_file_list {
	my $wiki = shift;
	my $page = shift;
	my $encode_page = &Util::url_encode($page);
	my @list;
	if(-e $wiki->config('attach_dir')){
		opendir(DIR,$wiki->config('attach_dir')) or die $!;
		while(my $entry = readdir(DIR)){
			if(index($entry,$encode_page.".")==0){
				my $file = (split(/\./,$entry))[1];
				push(@list,&Util::url_decode($file));
			}
		}
		closedir(DIR);
	}
	@list = sort { $a cmp $b } @list;
	return @list;
}

#===========================================================
# źեե뤬ǽɤȽꤹؿ
#===========================================================
sub can_attach_delete {
	my $wiki  = shift;
	my $page  = shift;
	my $login = $wiki->get_login_info();
	
	if(!$wiki->can_modify_page($page)){
		return 0;
	} elsif($wiki->config('accept_attach_delete')==0 && !defined($login)){
		return 0;
	} elsif($wiki->config('accept_attach_delete')==2 && (!defined($login) || $login->{type}!=0)){
		return 0;
	}
	
	return 1;
}

1;
